@@ -169,3 +169,19 @@ sqldf <- function(x, stringsAsFactors = TRUE, col.classes = NULL,
 	rs
 }
 
+
+read.csv.sql <- function(file, sql = "select * from file", 
+	header = TRUE, sep = ",", row.names, eol, skip, dbname = tempfile(), ...) {
+	file.format <- list(header = header, sep = sep)
+	if (!missing(eol)) 
+		file.format <- append(file.format, list(eol = eol))
+	if (!missing(row.names)) 
+		file.format <- append(file.format, list(row.names = row.names))
+	if (!missing(skip)) 
+		file.format <- append(file.format, list(skip = skip))
+	pf <- parent.frame()
+	p <- proto(pf, file = file(file))
+	p <- do.call(proto, list(pf, file = file(file)))
+	sqldf(sql, envir = p, file.format = file.format, dbname = dbname, ...)
+}
+
